[all-commits] [llvm/llvm-project] dd45ed: [mlir] Reduce generated assembly printer compile time
Mehdi Amini via All-commits
all-commits at lists.llvm.org
Wed Sep 23 04:54:25 PDT 2026
Branch: refs/heads/users/mamini/mlir-generated-printer-compile-time
Home: https://github.com/llvm/llvm-project
Commit: dd45ed8a619beb9b8f330fb9b64f879dad61b693
https://github.com/llvm/llvm-project/commit/dd45ed8a619beb9b8f330fb9b64f879dad61b693
Author: Mehdi Amini <joker.eph at gmail.com>
Date: 2026-09-23 (Wed, 23 Sep 2026)
Changed paths:
M mlir/include/mlir/IR/OpImplementation.h
M mlir/lib/IR/AsmPrinter.cpp
M mlir/test/mlir-tblgen/op-decl-and-defs.td
M mlir/test/mlir-tblgen/op-format.td
M mlir/tools/mlir-tblgen/OpDefinitionsGen.cpp
M mlir/tools/mlir-tblgen/OpFormatGen.cpp
Log Message:
-----------
[mlir] Reduce generated assembly printer compile time
Use fixed arrays for statically elided attributes and combine leading spaces
with literals. Move common operand printing out of generated call sites and
emit sliced operand getters to reduce optimizer work in large printers.
For omp.target, optimized print IR drops from 3,893 to 2,667 instructions.
The printing benchmark is 2.1% slower; check-mlir passes.
Assisted-by: Codex
To unsubscribe from these emails, change your notification settings at https://github.com/llvm/llvm-project/settings/notifications
More information about the All-commits
mailing list